@@ -1,8 +1,8 @@
 from .bases import *
 
 __copyright__ = "Copyright (C) 2020 Yuichiro Smith"
-__version__ = "0.2.2"
+__version__ = "0.2.4"
 __license__ = "Apache License 2.0"
 __author__ = "Yuichiro Smith"
 __author_email__ = "contact@yu-smith.com"
-__url__ = "http://github.com/aeroworks-io/python-ddd"
+__url__ = "http://github.com/aeroworks-io/dddpy"
